@@ -9,9 +9,9 @@ except ImportError:
 pr = cProfile.Profile()
 pr.enable()
 
-for _ in range(10000):
+for _ in range(1):
 
-    c = variable(4.182, 'J/kg-K', 130)
+    c = variable(4.182, 'J/kg-K', 0.130)
     rho = variable(1000, 'kg/m3', 0.01)
     t_in = variable(50, 'C', 1.2)
     t_out = variable([10, 15, 20, 25, 30, 35, 40], 'C', [0.9, 1.1, 1.0, 0.8, 0.9, 1.3, 1.1])
@@ -20,7 +20,6 @@ for _ in range(10000):
     q = c * rho * v_dot * (t_in - t_out)
     q.convert('kW')
 
-
 pr.disable()
 s = io.StringIO()
 ps = pstats.Stats(pr, stream=s).sort_stats('tottime')
