@@ -12,7 +12,7 @@ def prop(property, fluid, **kwargs):
     if not fluid in knownFluids:
         raise ValueError(f"The fluid {fluid} is unknown")
 
-    method = knownFluids[fluid][0]
+    method = knownFluids[fluid]
         
     return method(property, kwargs)
 
@@ -22,7 +22,7 @@ def isAllArgumentsUsed(arguments: dict):
 
 def findArgument(arguments : dict, parameterName, unitStr, raiseError = True):
 
-    desiredSIBaseUnit = unit(unitStr)._SIBaseUnit
+    desiredSIBaseUnit = unit(unitStr).unitStrSI
     
     parameter = None
     if  parameterName in arguments.keys():
@@ -32,7 +32,7 @@ def findArgument(arguments : dict, parameterName, unitStr, raiseError = True):
         if raiseError:
             raise ValueError(f'Could not find an arugment matching that of a {parameterName}')
     if not parameter is None:
-        if parameter._unitObject._SIBaseUnit != desiredSIBaseUnit:
+        if parameter._unitObject.unitStrSI != desiredSIBaseUnit:
             raise ValueError(f'The input {parameterName} did not have to correct unit of {unitStr}')
 
     return arguments, parameter
@@ -52,7 +52,6 @@ def differentialsBrine(fluid : Fluid, fluidName,  property, C, parameters):
     vars.append(C)
     return vars, grads
 
-
 def differentials(fluid : Fluid, property : str, parameters):
     vars = []
     indexes = []
@@ -61,9 +60,7 @@ def differentials(fluid : Fluid, property : str, parameters):
             indexes.append(i)
             vars.append(param)
     
-    
     inputs = list(fluid._inputs)
-
     
     grads = []
     for i in indexes:
@@ -86,43 +83,52 @@ def differentials(fluid : Fluid, property : str, parameters):
         grads.append((y2-y1) / (2*dx*i0.value))
     
     return vars, grads
-    
 
 def outputFromParameters(scalarMethod, property, params):
-
-    if (all([type(elem) == scalarVariable for elem in params if not elem is None])):
-        ## all inputs are scalars
-        out = scalarMethod(property, *params)
-        return out
     
-    out = []
-    ns = []
-    paramVecs = [None] * len(params)
-
-    for i, param in enumerate(params):
-        if type(param) == arrayVariable:
-            paramVecs[i] = param
-            ns.append(len(param))
+    ## determine which of the parameters that are arrayVariables
+    isArrayVariable = [hasattr(param, '__len__') for param in params]
     
-    if not (all([ns[0] == n] for n in ns)):
-        raise ValueError('All parameters has to have the same length')
+    ## return the scalarmethod if all parameters are scalarvariables
+    if sum(isArrayVariable) == 0:
+        return scalarMethod(property, *params)
     
-    if ns:
-        n = ns[0]
-        for i, param in enumerate(params):
-            if param is None:
-                paramVecs[i] = [None] * n
-            elif not type(param) == arrayVariable:
-                paramVecs[i] = variable([param.value] * n, param.unit, [param.uncert] * n)
-        for i in range(n):
-            params = [elem[i] for elem in paramVecs]
-            out.append(scalarMethod(property, *params))
-        return variable([elem.value for elem in out], out[0].unit, [elem.uncert for elem in out])
+    ## make sure, that all arrayVariables have the same length
+    indexesOfArrayVariables = [i for i, elem in enumerate(isArrayVariable) if elem == True]
+    n = len(params[indexesOfArrayVariables[0]])
+    for i in indexesOfArrayVariables:
+        if len(params[i]) != n:
+            raise ValueError('All parameters has to have the same length')
+    
+    ## create a list of scalar variables. This list will have the same length as the arrayVariables supplied
+    listOfScalarVariables = []
+    
+    ## loop over the length of the arrayVariables
+    for i in range(n):
         
-    return scalarMethod(property, *params)
+        ## create a list of scalarparameter
+        scalarParams = []
+        
+        ## loop over the parameters
+        for ii, param in enumerate(params):
+            
+            ## if the current parameter is an arrayVariable, then append the i'th scalarVaraible of the arrayVariable to the list of the scalar parameters
+            if ii in indexesOfArrayVariables:
+                scalarParams.append(param[i])
+            
+            ## if the current parameter is a scalarvariable, then simply append the parameter to the scalarparameters
+            else:
+                scalarParams.append(param)
+                
+        ## append the output of the scalarmethods to the list of scalar variables
+        listOfScalarVariables.append(scalarMethod(property, *scalarParams))
+        
+    ## return an arrayVariable, which is created from a list of scalarvariables
+    return arrayVariable(scalarVariables=listOfScalarVariables)
+    
+    
 
 def propWater(property, arguments):
-    
     ## find the appropriate arguments from the list
     arguments, T = findArgument(arguments, 'T', 'K')
     arguments, P = findArgument(arguments, 'P', 'Pa')
@@ -137,7 +143,7 @@ def propWater(property, arguments):
     P.convert('Pa')
     
     out = outputFromParameters(propWaterScalar, property, [T,P])
-        
+
     ## convert the arguments back in to the original units
     T.convert(Tunit)
     P.convert(Punit)
@@ -215,7 +221,6 @@ def propMEGScalar(property, T,P,C):
     ## return the variable
     return var
     
-
 def propHumidAir(property, arguments):
 
 
@@ -298,15 +303,19 @@ knownProperties = [
 ]
 
 knownFluids = {
-    'water': [propWater],
-    'MEG': [propMEG],
-    'air': [propHumidAir]
+    'water': propWater,
+    'MEG': propMEG,
+    'air': propHumidAir
 }
 
 
 if __name__ == "__main__":
+
+    # T = variable([20,25,30], 'C', [0.1, 0.2, 0.15])
+    # P = variable([1 * 1e5, 1.1 * 1e5, 1.2 * 1e5], 'Pa', [0.03 * 1e5, 0.04 * 1e5, 0.025 * 1e5])
     
-    T = variable([20,30], 'C', [1,1])
-    P = variable(1, 'bar', 0.01)
-    C = variable(50,'%', 2)
+    # rho = prop('density', 'water', T = T, P = P)
+    # print(rho)
+    P = variable(1, 'bar')
+    print(P._unitObject._converterToSI.scale)
     
\ No newline at end of file
