@@ -76,14 +76,17 @@ class _fileFromSheets():
                     meas = object
  
                     self.write(worksheet, 0, col, objectName)
-                    self.write(worksheet, 1, col, meas.unit)
+                    unit = '-' if meas.unit == '1' else meas.unit
+                    self.write(worksheet, 1, col, unit)
                     
                     u = meas.unit
                     scale = variable(1, u)
                     meas /= scale
                     
                     for row, val in enumerate(meas):
-                        self.write(worksheet, row + 2, col, str(val))
+                        string = str(val)
+                        string = string.replace('+/-', '±\n')
+                        self.write(worksheet, row + 2, col, string)
                     
                     meas *= scale
                                                 
@@ -117,7 +120,7 @@ class _sheetsFromFile():
 
         # parse functions for the specific extension and get all sheets
         if extension == '.xls':
-            self.wb = xlrd.open_workbook(xlFile)
+            self.wb = xlrd.open_workbook(xlFile, formatting_info=True)
             
             self.sheets = self.wb.sheets()
             if not sheets is None:
@@ -126,7 +129,11 @@ class _sheetsFromFile():
                 self.sheets = [elem for i,elem in enumerate(self.sheets) if i in sheets]
 
             def readCell(sheet, row, col):
-                return sheet.cell(row, col).value
+                cell = sheet.cell(row,col)
+                if cell.ctype == 2:
+                    return cell.value
+                else:
+                    return np.nan
 
             def readRow(sheet, row):
                 return [elem.value for elem in sheet.row(row)]
@@ -143,7 +150,12 @@ class _sheetsFromFile():
                 self.sheets = [elem for i,elem in enumerate(self.sheets) if i in sheets]
                 
             def readCell(sheet, row, col):
-                return sheet.cell(row + 1, col + 1).value
+                cell = sheet.cell(row+1,col+1)
+                try:
+                    float(cell.value)
+                    return cell.value
+                except ValueError:
+                    return np.nan
 
             def readRow(sheet, row):
                 return [elem.value for elem in list(sheet.iter_rows())[row]]
@@ -228,6 +240,7 @@ class _sheetsFromFile():
         return num
 
     def formatHeaders(self, header):
+
         out = []
         for head in header:
             if head is None:
@@ -235,15 +248,14 @@ class _sheetsFromFile():
                 continue
             # remove symbols and replace with _
             head = re.sub(r'[^\w]', '_', head)
-
+            
             # remove multiple consequtive _
             done = False
-            a = head
             while not done:
-                b = a.replace('__', '_')
-                if a == b:
+                head = head.replace('__', '_')
+                if not '__' in head:
                     done = True
-
+                         
             # add "_" to the begining of the name if the first letter is a digit
             if head[0].isnumeric():
                 head = '_' + head
@@ -444,5 +456,9 @@ class sheet():
         
         return iter(variables)
     
-    
-    
\ No newline at end of file
+    def pop(self, index = -1):
+        for key, item in self.__dict__.items():
+            if isinstance(item, scalarVariable):
+                item.pop(index)
+
+
