@@ -1,11 +1,12 @@
 import unittest
 import numpy as np
-from random import uniform
 try:
     from variable import variable
+    from unit import unit
 except ImportError:
     from pyees.variable import variable
-
+    from pyees.unit import unit
+    
 class test(unittest.TestCase): 
 
     def testSingleNumber(self):
@@ -88,6 +89,12 @@ class test(unittest.TestCase):
                 np.sqrt((1 * 10.56 * 1000 * 60)**2 + (1 * 6.4 * 1000 * 60)**2),
             ]))
 
+        A = variable(7, '%', 0.1)
+        B = 1 + A
+        self.assertAlmostEqual(B.value, 8)
+        self.assertEqual(B.unit, '%')
+        self.assertEqual(B.uncert, 0.1)
+
     def test_sub(self):
         A = variable(12.3, 'L/min', uncert=2.6)
         B = variable(745.1, 'L/min', uncert=53.9)
@@ -115,6 +122,12 @@ class test(unittest.TestCase):
                 np.sqrt((1 * 10.56)**2 + (1 * 6.4)**2),
             ]))
 
+        A = variable(7, '%', 0.1)
+        B = 1 - A
+        self.assertAlmostEqual(B.value, -6)
+        self.assertEqual(B.unit, '%')
+        self.assertEqual(B.uncert, 0.1)
+
     def test_add_with_different_units(self):
         A = variable(12.3, 'm3/s', uncert=2.6)
         B = variable(745.1, 'L/min', uncert=53.9)
@@ -221,6 +234,13 @@ class test(unittest.TestCase):
         self.assertAlmostEqual(c.value, 10 - 100 * 1e-6)
         self.assertEqual(c.unit, 'DELTAC')
         self.assertEqual(c.uncert, np.sqrt((1 * 1.2)**2 + (1 * 3.9*1e-6)**2))
+        
+        a = variable(100, 'muC', 3.9)
+        b = variable(10, 'C', 1.2)
+        c = a - b
+        self.assertAlmostEqual(c.value, -10 + 100 * 1e-6)
+        self.assertEqual(c.unit, 'DELTAC')
+        self.assertEqual(c.uncert, np.sqrt((1 * 1.2)**2 + (1 * 3.9*1e-6)**2))
 
     def test_multiply(self):
         A = variable(12.3, 'L/min', uncert=2.6)
@@ -231,12 +251,12 @@ class test(unittest.TestCase):
         C = A * B
 
         self.assertAlmostEqual(C.value, 12.3 * 745.1)
-        self.assertTrue(C._unitObject._assertEqual('L-m/min'))
+        self.assertTrue(C._unitObject == unit('L-m/min'))
         self.assertAlmostEqual(C.uncert, np.sqrt((745.1 * 2.6)**2 + (12.3 * 53.9)**2))
 
         C_vec = A_vec * B_vec
         np.testing.assert_array_equal(C_vec.value, np.array([12.3 * 745.1, 54.3 * 496.13, 91.3 * 120.54]))
-        self.assertTrue(C._unitObject._assertEqual('L-m/min'))
+        self.assertTrue(C._unitObject == unit('L-m/min'))
         np.testing.assert_array_almost_equal(
             C_vec.uncert,
             np.array([
@@ -247,7 +267,7 @@ class test(unittest.TestCase):
 
         C_vec.convert('m3-km / s')
         np.testing.assert_array_equal(C_vec.value, np.array([12.3 * 745.1, 54.3 * 496.13, 91.3 * 120.54]) / 1000 / 1000 / 60)
-        self.assertEqual(C_vec.unit, 'm3-km/s')
+        self.assertTrue(C_vec._unitObject == unit('m3-km/s'))
         np.testing.assert_almost_equal(
             C_vec.uncert,
             np.array([
@@ -260,7 +280,7 @@ class test(unittest.TestCase):
         b = variable(7.43, 'N/cm', 2.5)
         c = a * b
         self.assertAlmostEqual(c.value, 891.6)
-        self.assertEqual(c.unit, '1')
+        self.assertTrue(c._unitObject == unit('1'))
         self.assertAlmostEqual(c.uncert, 320.032970958)
 
     def test_divide(self):
@@ -271,17 +291,17 @@ class test(unittest.TestCase):
 
         C = A / B
         self.assertAlmostEqual(C.value, 12.3 / 745.1)
-        self.assertTrue(C._unitObject._assertEqual('L/min-m'))
+        self.assertTrue(C._unitObject == unit('L/min-m'))
         self.assertAlmostEqual(C.uncert, np.sqrt((1 / 745.1 * 2.6)**2 + (12.3 / (745.1**2) * 53.9)**2))
 
         C.convert('m3/h-mm')
         self.assertAlmostEqual(C.value, 12.3 / 745.1 / 1000 * 60 / 1000)
-        self.assertEqual(C.unit, 'm3/h-mm')
+        self.assertTrue(C._unitObject == unit('m3/h-mm'))
         self.assertAlmostEqual(C.uncert, np.sqrt((1 / (745.1 * 1000) * 2.6 / 1000 * 60)**2 + (12.3 / ((745.1)**2) * 53.9 / 1000 * 60 / 1000)**2))
 
         C_vec = A_vec / B_vec
         np.testing.assert_array_equal(C_vec.value, np.array([12.3 / 745.1, 54.3 / 496.13, 91.3 / 120.54]))
-        self.assertTrue(C_vec._unitObject._assertEqual('L/min-m'))
+        self.assertTrue(C_vec._unitObject == unit('L/min-m'))
         np.testing.assert_array_almost_equal(
             C_vec.uncert,
             np.array([
@@ -292,7 +312,7 @@ class test(unittest.TestCase):
 
         C_vec.convert('m3 / h -mm')
         np.testing.assert_almost_equal(C_vec.value, np.array([12.3 / 745.1, 54.3 / 496.13, 91.3 / 120.54]) / 1000 * 60 / 1000)
-        self.assertEqual(C_vec.unit, 'm3/h-mm')
+        self.assertTrue(C_vec._unitObject == unit('m3/h-mm')) 
         np.testing.assert_almost_equal(
             C_vec.uncert,
             np.array([
@@ -689,7 +709,7 @@ class test(unittest.TestCase):
 
         A *= B
         self.assertAlmostEqual(A.value, 12.3 * 745.1)
-        self.assertTrue(A._unitObject._assertEqual('L-m/min'))
+        self.assertTrue(A._unitObject, unit('L-m/min'))
         self.assertAlmostEqual(A.uncert, np.sqrt((745.1 * 2.6)**2 + (12.3 * 53.9)**2))
 
         A = variable(12.3, 'L/min', uncert=2.6)
@@ -710,7 +730,7 @@ class test(unittest.TestCase):
 
         A_vec *= B_vec
         np.testing.assert_array_almost_equal(A_vec.value, np.array([12.3 * 745.1, 54.3 * 496.13, 91.3 * 120.54]))
-        self.assertTrue(A_vec._unitObject._assertEqual('L-m/min'))
+        self.assertTrue(A_vec._unitObject, unit('L-m/min'))
         np.testing.assert_array_almost_equal(
             A_vec.uncert,
             np.array([
@@ -738,20 +758,20 @@ class test(unittest.TestCase):
 
         A /= B
         self.assertAlmostEqual(A.value, 12.3 / 745.1)
-        self.assertTrue(A._unitObject._assertEqual('L/min-m'))
+        self.assertTrue(A._unitObject == unit('L/min-m'))
         self.assertAlmostEqual(A.uncert, np.sqrt((1 / 745.1 * 2.6)**2 + (12.3 / (745.1**2) * 53.9)**2))
 
         A = variable(12.3, 'L/min', uncert=2.6)
         A /= 2
         self.assertAlmostEqual(A.value, 12.3 / 2)
-        self.assertEqual(A.unit, 'L/min')
+        self.assertTrue(A._unitObject == unit('L/min'))
         self.assertAlmostEqual(A.uncert, np.sqrt((1 / 2 * 2.6)**2))
 
         A = variable(12.3, 'L/min', uncert=2.6)
         B = 2
         B /= A
         self.assertAlmostEqual(B.value, 2 / 12.3)
-        self.assertEqual(B.unit, 'min/L')
+        self.assertTrue(B._unitObject == unit('min/L'))
         self.assertAlmostEqual(B.uncert, np.sqrt((2 / (12.3**2) * 2.6)**2))
 
         A_vec = variable([12.3, 54.3, 91.3], 'L/min', uncert=[2.6, 5.4, 10.56])
@@ -759,7 +779,7 @@ class test(unittest.TestCase):
 
         A_vec /= B_vec
         np.testing.assert_array_almost_equal(A_vec.value, np.array([12.3 / 745.1, 54.3 / 496.13, 91.3 / 120.54]))
-        self.assertTrue(A_vec._unitObject._assertEqual('L/min-m'))
+        self.assertTrue(A_vec._unitObject == unit('L/min-m'))
         np.testing.assert_array_almost_equal(
             A_vec.uncert,
             np.array([
@@ -772,7 +792,7 @@ class test(unittest.TestCase):
         A = variable(12.3, 'L/min', uncert=2.6)
         A_vec /= A
         np.testing.assert_array_almost_equal(A_vec.value, np.array([12.3 / 12.3, 54.3 / 12.3, 91.3 / 12.3]))
-        self.assertEqual(A_vec.unit, '1')
+        self.assertTrue(A_vec._unitObject, unit('1'))
         np.testing.assert_array_almost_equal(
             A_vec.uncert,
             np.array([
@@ -853,6 +873,7 @@ class test(unittest.TestCase):
         self.assertEqual(str(A), '1.23e-08 [m]')
 
     def testRoot(self):
+        from random import uniform
         A = variable(10, 'L2/min2')
         a = np.sqrt(A)
         self.assertEqual(a.value, np.sqrt(10))
@@ -920,8 +941,6 @@ class test(unittest.TestCase):
         
         A = variable(0.9, 'L/min', 3)
         self.assertEqual(str(A), '1 +/- 3 [L/min]')
-        
-        
 
     def testUnitless(self):
         with self.assertRaises(Exception) as context:
@@ -1185,12 +1204,12 @@ class test(unittest.TestCase):
         self.assertAlmostEqual(b.value, 3361.3445378151260504201680672269)
         self.assertEqual(b.unit, 'L2/min2')
         self.assertAlmostEqual(b.uncert, np.sqrt((1.5 * 0.16806722689075630252100840336134 * 200)**2))
-
+       
         b *= np.sin(a * variable(1, 'rad-min/L'))
         self.assertAlmostEqual(b.value, -2935.453099878973383976532508069948132551783965504369163751)
         self.assertEqual(b.unit, 'L2/min2')
         self.assertAlmostEqual(b.uncert, np.sqrt((1.5 * 2 * 200 * (2 * np.sin(200) + 200 * np.cos(200)) / 23.8)**2))
-
+                
         a /= variable(100, 'L/min')
         a.convert('')
         b /= np.exp(a)
@@ -1240,7 +1259,7 @@ class test(unittest.TestCase):
         a.addCovariance(b, 23, 'L-Pa/min')
         c = a * b
         self.assertEqual(c.value, 123 * 93)
-        self.assertTrue(c._unitObject._assertEqual('L-Pa/min'))
+        self.assertTrue(c._unitObject ==unit('L-Pa/min'))
         self.assertAlmostEqual(c.uncert, np.sqrt((123 * 1.2)**2 + (93 * 9.7)**2 + 2 * 93 * 123 * 23))
 
         a = variable(123, 'L/min', 9.7)
@@ -1249,7 +1268,7 @@ class test(unittest.TestCase):
         a.convert('m3/s')
         c = a * b
         self.assertEqual(c.value, 123 * 93 / 1000 / 60)
-        self.assertTrue(c._unitObject._assertEqual('m3-Pa/s'))
+        self.assertTrue(c._unitObject ==unit('m3-Pa/s'))
         self.assertEqual(c.uncert, np.sqrt((123 / 1000 / 60 * 1.2)**2 + (93 * 9.7 / 1000 / 60)**2 + 2 * 93 * 123 / 1000 / 60 * 23 / 1000 / 60))
         
         a = variable(123, 'L/min', 9.7)
@@ -1258,15 +1277,15 @@ class test(unittest.TestCase):
         a.convert('m3/s')
         c = a * b
         self.assertEqual(c.value, 123 * 93 / 1000 / 60)
-        self.assertTrue(c._unitObject._assertEqual('m3-Pa/s'))
-        self.assertEqual(c.uncert, np.sqrt((123 / 1000 / 60 * 1.2)**2 + (93 * 9.7 / 1000 / 60)**2 + 2 * 93 * 123 / 1000 / 60 * 23))
+        self.assertTrue(c._unitObject ==unit('m3-Pa/s'))
+        self.assertAlmostEqual(c.uncert, np.sqrt((123 / 1000 / 60 * 1.2)**2 + (93 * 9.7 / 1000 / 60)**2 + 2 * 93 * 123 / 1000 / 60 * 23))
         
         a = variable([1, 2, 3], 'L/min', [0.1, 0.2 ,0.3])
         b = variable([93, 97, 102], 'Pa', [1.2, 2.4, 4.7])
         a.addCovariance(b, [2, 3, 4], 'L-Pa/min')
         c = a * b
         np.testing.assert_equal(c.value, [1*93, 2*97, 3*102])
-        self.assertTrue(c._unitObject._assertEqual('L-Pa/min'))
+        self.assertTrue(c._unitObject ==unit('L-Pa/min'))
         dcda = np.array([93, 97, 102], dtype = float)
         dcdb = np.array([1, 2, 3], dtype = float)
         ua = np.array([0.1, 0.2, 0.3], dtype = float)
@@ -1290,14 +1309,31 @@ class test(unittest.TestCase):
         area.convert('m2')
         self.assertEqual(area.value, 0.12566370614359172953850573)
         self.assertEqual(area.unit, 'm2')
-        self.assertEqual(area.uncert, np.sqrt((2 * np.pi / 4 * 0.4 * 0.002)**2))
-        
-        
-        
-        
-         
-        
+        self.assertEqual(area.uncert, np.sqrt((2 * np.pi / 4 * 0.4 * 0.002)**2))  
 
+        time = variable([1,2,3], 's', [0.1, 0.2, 0.3])
+        time.convert('min')
+        np.testing.assert_array_equal(time.value, np.array([1,2,3]) / 60)
+        self.assertEqual(time.unit, 'min')
+        np.testing.assert_array_equal(time.uncert, np.array([0.1,0.2,0.3]) / 60)
+        self.assertEqual(time[0].value, 1/60)
+        self.assertEqual(time[1].value, 2/60)
+        self.assertEqual(time[2].value, 3/60)
+        self.assertEqual(time[0].unit, 'min')
+        self.assertEqual(time[1].unit, 'min')
+        self.assertEqual(time[2].unit, 'min')
+        self.assertEqual(time[0].uncert, 0.1/60)
+        self.assertEqual(time[1].uncert, 0.2/60)
+        self.assertEqual(time[2].uncert, 0.3/60)
+
+
+        t1 = variable([1,2,3], 'min')
+        t1[1].convert('s')
+        dt = variable(10, 'min')
+        with self.assertRaises(Exception) as context:
+            t1 + dt
+        self.assertTrue("Some of the scalarvariables in [1, 120, 3] [min] did not have the unit [min] as they should. This could happen if the user has converted a scalarVaraible instead of the arrayVaraible." in str(context.exception))
+        
     def testCompare(self):
         a = variable(1, 'm')
         b = variable([2, 3, 4], 'm')
@@ -1307,7 +1343,7 @@ class test(unittest.TestCase):
         np.testing.assert_equal(a >= b, [False, False, False])
         np.testing.assert_equal(a == b, [False, False, False])
         np.testing.assert_equal(a != b, [True, True, True])
-
+        
         a = variable([2, 3, 4], 'm')
         b = variable(1, 'm')
         np.testing.assert_equal(a < b, [False, False, False])
@@ -1320,54 +1356,54 @@ class test(unittest.TestCase):
         a = variable([1, 2], 'm')
         b = variable([2, 3, 4], 'm')
         with self.assertRaises(Exception) as context:
-            c = a < b
+            a < b
         self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a <= b
+            a <= b
         self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a > b
+            a > b
         self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a >= b
+            a >= b
         self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a == b
+            a == b
         self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a != b
+            a != b
         self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
         
         
         a = variable(1, 'm')
         b = variable(2, 'C')
         with self.assertRaises(Exception) as context:
-            c = a < b
+            a < b
         self.assertTrue("You cannot compare 1 [m] and 2 [C] as they do not have the same SI base unit" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a <= b
+            a <= b
         self.assertTrue("You cannot compare 1 [m] and 2 [C] as they do not have the same SI base unit" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a > b
+            a > b
         self.assertTrue("You cannot compare 1 [m] and 2 [C] as they do not have the same SI base unit" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a >= b
+            a >= b
         self.assertTrue("You cannot compare 1 [m] and 2 [C] as they do not have the same SI base unit" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a == b
+            a == b
         self.assertTrue("You cannot compare 1 [m] and 2 [C] as they do not have the same SI base unit" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            c = a != b
+            a != b
         self.assertTrue("You cannot compare 1 [m] and 2 [C] as they do not have the same SI base unit" in str(context.exception))
 
         a = variable([1, 2, 3], 'm')
@@ -1463,18 +1499,17 @@ class test(unittest.TestCase):
         c2 *= a2
         
         np.testing.assert_equal(C[0].value, c0.value)
-        self.assertTrue(C._unitObject._assertEqual(c0.unit))
+        self.assertTrue(C._unitObject == unit(c0.unit))
         np.testing.assert_equal(C[0].uncert, c0.uncert)
         
         np.testing.assert_equal(C[1].value, c1.value)
-        self.assertTrue(C._unitObject._assertEqual(c0.unit))
+        self.assertTrue(C._unitObject == unit(c0.unit))
         np.testing.assert_equal(C[1].uncert, c1.uncert)
         
         np.testing.assert_equal(C[2].value, c2.value)
-        self.assertTrue(C._unitObject._assertEqual(c0.unit))
+        self.assertTrue(C._unitObject == unit(c0.unit))
         np.testing.assert_equal(C[2].uncert, c2.uncert)
-
-              
+      
     def testAppend(self):
         A = variable(12.3, 'L/min', uncert=2.6)
         B = variable(45, 'Pa', 1.2)
@@ -1508,8 +1543,8 @@ class test(unittest.TestCase):
         d = a * c
 
         np.testing.assert_equal(d.value, np.array([1,2,3,4,5,6]) * np.array([10,11,12,13,14,15]))
-        self.assertTrue(d._unitObject._assertEqualStatic(d.unit, 'm-Pa'))        
-        np.testing.assert_equal(d.uncert, np.sqrt(2 * np.array([1,2,3,4,5,6]) * np.array([10,11,12,13,14,15]) * np.array([0,0,0,0.1,0.2,0.3])))
+        self.assertTrue(d._unitObject == unit('m-Pa'))        
+        np.testing.assert_array_almost_equal(d.uncert, np.sqrt(2 * np.array([1,2,3,4,5,6]) * np.array([10,11,12,13,14,15]) * np.array([0,0,0,0.1,0.2,0.3])))
         
         
         a = variable([1, 2, 3], 'm')
@@ -1521,10 +1556,9 @@ class test(unittest.TestCase):
         c.append(d) 
         d = a * c
         np.testing.assert_equal(d.value, np.array([1,2,3,4,5,6]) * np.array([10,11,12,13,14,15]))
-        self.assertTrue(d._unitObject._assertEqualStatic(d.unit, 'm-Pa'))        
+        self.assertTrue(d._unitObject == unit('m-Pa'))        
         np.testing.assert_equal(d.uncert, np.array([0,0,0,0,0,0]))
         
-        
     def testAddBel(self):
         a = variable(11,'dB', 0.1)
         b = variable(19,'dB',1.2)
@@ -1748,9 +1782,8 @@ class test(unittest.TestCase):
         gradA = -10**(1.1+1) / (10**(19/10) - 10**1.1)
         gradB = 10**(19/10) / (10**(19/10) - 10**1.1)
         self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
-      
 
-    def testTemperatureArithmatic(self):
+    def testTemperatureAddition(self):
         a = variable(20,'C')
         b = variable(30,'C')
         c = a + b
@@ -1775,35 +1808,6 @@ class test(unittest.TestCase):
         self.assertEqual(c.value, 50)
         self.assertEqual(c.unit, 'DELTAC')
         
-        
-        a = variable(20,'C')
-        b = variable(30,'C')
-        c = a - b
-        self.assertEqual(c.value, -10)
-        self.assertEqual(c.unit, 'DELTAC')
-        
-        a = variable(20,'C')
-        b = variable(30,'DELTAC')
-        c = a - b
-        self.assertEqual(c.value, -10)
-        self.assertEqual(c.unit, 'C')
-        
-        a = variable(20,'DELTAC')
-        b = variable(30,'C')
-        with self.assertRaises(Exception) as context:
-            c = a - b
-        self.assertTrue("You tried to subtract a temperature from a temperature differnce. This is not possible." in str(context.exception))
-
-        
-        a = variable(20,'DELTAC')
-        b = variable(30,'DELTAC')
-        c = a - b
-        self.assertEqual(c.value, -10)
-        self.assertEqual(c.unit, 'DELTAC')
-        
-        
-        
-        
         a = variable(100,'K')
         b = variable(20, 'C')
         c = a + b 
@@ -1828,8 +1832,31 @@ class test(unittest.TestCase):
         self.assertEqual(c.value, 120)
         self.assertEqual(c.unit, 'DELTAK')
         
+    def testTemperatureSubtraction(self):
+        a = variable(20,'C')
+        b = variable(30,'C')
+        c = a - b
+        self.assertEqual(c.value, -10)
+        self.assertEqual(c.unit, 'DELTAC')
         
+        a = variable(20,'C')
+        b = variable(30,'DELTAC')
+        c = a - b
+        self.assertEqual(c.value, -10)
+        self.assertEqual(c.unit, 'C')
         
+        a = variable(20,'DELTAC')
+        b = variable(30,'C')
+        with self.assertRaises(Exception) as context:
+            c = a - b
+        self.assertTrue("You tried to subtract a temperature from a temperature differnce. This is not possible." in str(context.exception))
+
+        a = variable(20,'DELTAC')
+        b = variable(30,'DELTAC')
+        c = a - b
+        self.assertEqual(c.value, -10)
+        self.assertEqual(c.unit, 'DELTAC')
+              
         a = variable(100,'K')
         b = variable(20, 'C')
         c = a - b 
@@ -1861,7 +1888,7 @@ class test(unittest.TestCase):
         self.assertEqual(c.value, 100 - 20)
         self.assertEqual(c.unit, 'DELTAK')
         
-        
+    def testTemperatureMean(self):
         a = variable(20,'C')
         b = variable(30,'C')
         c = np.mean([a,b])
@@ -1874,7 +1901,25 @@ class test(unittest.TestCase):
         self.assertEqual(c.value, 25)
         self.assertEqual(c.unit, 'C')
                 
+    def testPop(self):
         
+        A_vec = variable([12.3, 54.3, 91.3], 'L/min', uncert=[2.6, 5.4, 10.56])
+        A_vec.pop(0)
+        np.testing.assert_equal(A_vec.value, [54.3, 91.3])
+        self.assertEqual(A_vec.unit,'L/min')
+        np.testing.assert_equal(A_vec.uncert, [5.4, 10.56])
+        
+        A_vec = variable([12.3, 54.3, 91.3], 'L/min', uncert=[2.6, 5.4, 10.56])
+        A_vec.pop(1)
+        np.testing.assert_equal(A_vec.value, [12.3, 91.3])
+        self.assertEqual(A_vec.unit,'L/min')
+        np.testing.assert_equal(A_vec.uncert, [2.6, 10.56])
+        
+        A_vec = variable([12.3, 54.3, 91.3], 'L/min', uncert=[2.6, 5.4, 10.56])
+        A_vec.pop(2)
+        np.testing.assert_equal(A_vec.value, [12.3, 54.3])
+        self.assertEqual(A_vec.unit,'L/min')
+        np.testing.assert_equal(A_vec.uncert, [2.6, 5.4])
         
 
 if __name__ == '__main__':
